Alternatives
============

Before diving in and spitting out this package I looked at the alternatives
below.  If I have missed something please drop me a mail_.

It isn’t meant to be unbiased, and you should try the packages out for
yourself.  I keep it here mainly as a reference for myself, and maybe to help
out people who are already familiar with one of the entries below.

.. _mail: jnrowe@gmail.com

.. todo::

   Transfer text from #338916
